@@ -21,9 +21,11 @@ use XML::Entities;
 use XML::Entities::Data;
 use Time::HiRes qw(gettimeofday sleep);
 use Lingua::Identify qw(langof);
+use Image::Magick;
+use File::ShareDir qw/dist_dir/;
 binmode(STDOUT,':utf8');
 
-our $VERSION = 0.28;
+our $VERSION = 0.29;
 
 =head1 NAME
 
@@ -31,6 +33,11 @@ FB3::Convert - scripts and API for converting FB3 from and to different formats
 
 =cut
 
+my $Dist = dist_dir('FB3-Convert');
+my $ProfilesDir = $Dist."/profiles";
+my $CMYKProfile = $ProfilesDir.'/CoatedFOGRA27.icc';
+my $sRGBProfile = $ProfilesDir.'/sRGB_Color_Space.icc';
+
 my %MODULES;
 # каким плагином работать - определяется тупо по расширению файла (см. ключ в хэше)
 %MODULES = (
@@ -98,7 +105,13 @@ our $ElsMainList2={};
 map {$ElsMainList2->{$_}=undef;} keys %$ElsMainList;
 $ElsMainList2->{p}=undef;
 
-my @AccessImgFormat = ('png','gif','jpg','jpeg','svg');
+my @AccessImgFormat = ('png','gif','jpg','jpeg','svg','bmp','tiff','tif',
+'cur','tga','vda','icb','vst'#<-targa
+);
+my @ConvertImgFormat = ('bmp','tiff','tif',
+'cur','tga','vda','icb','vst'
+);
+my %UseImgProfile = ('tiff'=>1,'tif'=>1);
 
 my %AllowElementsMain = (
   'table' => {
@@ -1392,6 +1405,18 @@ sub _bf {
 
 }
 
+sub isUseImageProfile {
+  my $X = shift;
+  my $ImgType = lc(shift) || return;
+  return 1 if exists $UseImgProfile{$ImgType} && $UseImgProfile{$ImgType};
+}
+
+sub isConvertImageType {
+  my $X = shift;
+  my $ImgType = shift || return;
+  return grep {lc($ImgType) eq $_} @ConvertImgFormat;
+}
+
 sub isAllowedImageType {
   my $X = shift;
   my $ImgType = shift || return;
@@ -1410,6 +1435,54 @@ sub GuessLang {
   }
 }
 
+sub Img2JPG {
+  my $X = shift;
+  my $ImgFile = shift;
+  my $UseProfile = shift || undef;
+  my $To = $ImgFile.".jpg";
+  my $Image = new Image::Magick;
+
+  $Image->Read($ImgFile); #почему-то у IM "or die" всегда срабатывает...;
+  
+  if ($UseProfile) {  
+    if (!-s $sRGBProfile) {
+      $X->Msg("Can't find sRGB ICC profile $sRGBProfile. Try convert to RGB colorspace without profile. May wrong colors for CMYK->RGB\n");
+      $Image->Quantize(colorspace=>'sRGB');
+    } elsif (!-s $CMYKProfile) {
+      $X->Msg("Can't find CMYK ICC profile $CMYKProfile. Try convert to RGB colorspace without profile. May wrong colors for CMYK->RGB\n");
+      $Image->Quantize(colorspace=>'sRGB');
+    } else {
+      
+      #вытираем профили 
+      $Image->Profile(name => 'ICC', profile => '');
+      $Image->Profile(name => 'IPTC', profile => '');
+
+      open my $PHRGB,"<".$sRGBProfile or die $!;
+      binmode($PHRGB);
+      my $ProfRGBBLOB = join("", <$PHRGB>); 
+      close $PHRGB;
+
+      open my $PHCMYK,"<".$CMYKProfile or die $!;
+      binmode($PHCMYK);
+      my $ProfCMYKBLOB = join("", <$PHCMYK>); 
+      close $PHCMYK;
+
+      $Image->Profile(name => 'ICC', profile => $ProfCMYKBLOB);
+      $Image->Profile(name => 'ICC', profile => $ProfRGBBLOB);
+ 
+     }
+  }
+
+  $Image->Write($To);
+
+  unless (-s $To) {
+    $X->Error("Cant't convert $ImgFile to JPG");
+  } else {
+    unlink($ImgFile);
+    return $To;
+  }
+}
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright (C) 2018 Litres.ru
